@@ -52,7 +52,9 @@ def set_exam(*, exam, json):
 @as_list
 def get_roster(*, exam):
     db = firestore.Client()
-    for student in db.collection("roster").document(exam).collection("deadline").stream():
+    for student in (
+        db.collection("roster").document(exam).collection("deadline").stream()
+    ):
         yield student.id, student.to_dict()["deadline"]
 
 
@@ -132,12 +134,8 @@ def process_ok_exam_upload(*, exam, data, clear=True):
     """
     db = firestore.Client()
 
-    db.collection("exam-alerts").document(exam).set(
-        {"questions": data["questions"]}
-    )
-    ref = (
-        db.collection("exam-alerts").document(exam).collection("students")
-    )
+    db.collection("exam-alerts").document(exam).set({"questions": data["questions"]})
+    ref = db.collection("exam-alerts").document(exam).collection("students")
     if clear:
         clear_collection(db, ref)
 
